summaryrefslogtreecommitdiffstats
path: root/src/memblockq.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/memblockq.h')
-rw-r--r--src/memblockq.h40
1 files changed, 20 insertions, 20 deletions
diff --git a/src/memblockq.h b/src/memblockq.h
index d19aac0e..d8b9567f 100644
--- a/src/memblockq.h
+++ b/src/memblockq.h
@@ -6,46 +6,46 @@
#include "memblock.h"
#include "memchunk.h"
-struct memblockq;
+struct pa_memblockq;
/* Parameters: the maximum length of the memblock queue, a base value
for all operations (that is, all byte operations shall work on
multiples of this base value) and an amount of bytes to prebuffer
-before having memblockq_peek() succeed. */
-struct memblockq* memblockq_new(size_t maxlength, size_t base, size_t prebuf);
-void memblockq_free(struct memblockq*bq);
+before having pa_memblockq_peek() succeed. */
+struct pa_memblockq* pa_memblockq_new(size_t maxlength, size_t base, size_t prebuf);
+void pa_memblockq_free(struct pa_memblockq*bq);
/* Push a new memory chunk into the queue. Optionally specify a value for future cancellation. This is currently not implemented, however! */
-void memblockq_push(struct memblockq* bq, const struct memchunk *chunk, size_t delta);
+void pa_memblockq_push(struct pa_memblockq* bq, const struct pa_memchunk *chunk, size_t delta);
-/* Same as memblockq_push(), however chunks are filtered through a mcalign object, and thus aligned to multiples of base */
-void memblockq_push_align(struct memblockq* bq, const struct memchunk *chunk, size_t delta);
+/* Same as pa_memblockq_push(), however chunks are filtered through a mcalign object, and thus aligned to multiples of base */
+void pa_memblockq_push_align(struct pa_memblockq* bq, const struct pa_memchunk *chunk, size_t delta);
/* Return a copy of the next memory chunk in the queue. It is not removed from the queue */
-int memblockq_peek(struct memblockq* bq, struct memchunk *chunk);
+int pa_memblockq_peek(struct pa_memblockq* bq, struct pa_memchunk *chunk);
/* Drop the specified bytes from the queue */
-void memblockq_drop(struct memblockq *bq, size_t length);
+void pa_memblockq_drop(struct pa_memblockq *bq, size_t length);
-/* Shorten the memblockq to the specified length by dropping data at the end of the queue */
-void memblockq_shorten(struct memblockq *bq, size_t length);
+/* Shorten the pa_memblockq to the specified length by dropping data at the end of the queue */
+void pa_memblockq_shorten(struct pa_memblockq *bq, size_t length);
-/* Empty the memblockq */
-void memblockq_empty(struct memblockq *bq);
+/* Empty the pa_memblockq */
+void pa_memblockq_empty(struct pa_memblockq *bq);
-/* Test if the memblockq is currently readable, that is, more data than base */
-int memblockq_is_readable(struct memblockq *bq);
+/* Test if the pa_memblockq is currently readable, that is, more data than base */
+int pa_memblockq_is_readable(struct pa_memblockq *bq);
-/* Test if the memblockq is currently writable for the specified amount of bytes */
-int memblockq_is_writable(struct memblockq *bq, size_t length);
+/* Test if the pa_memblockq is currently writable for the specified amount of bytes */
+int pa_memblockq_is_writable(struct pa_memblockq *bq, size_t length);
/* The time memory chunks stay in the queue until they are removed completely in usecs */
-uint32_t memblockq_get_delay(struct memblockq *bq);
+uint32_t pa_memblockq_get_delay(struct pa_memblockq *bq);
/* Return the length of the queue in bytes */
-uint32_t memblockq_get_length(struct memblockq *bq);
+uint32_t pa_memblockq_get_length(struct pa_memblockq *bq);
/* Return how many bytes are missing in queue to the specified fill amount */
-uint32_t memblockq_missing_to(struct memblockq *bq, size_t qlen);
+uint32_t pa_memblockq_missing_to(struct pa_memblockq *bq, size_t qlen);
#endif